function featuredata = featureSet(skeleton, motion, selector, verbose)
%
% choose different feature sets
% 
% INPUT
%   skeleton ... skeleton struct
%   motion ..... motion struct
%   selector ... string containing the feature set identificator
%   verbose .... true => print information
%                false => don't
%
% OUTPUT
%   featuredata ... <#frames-c x dim> matrix containing the feature data
%                   #frames is the number of frames in the motion
%                   c \in {1,5} is a constant as some features encode time (velocity for example)
%                   dim is the dimensionality of the feature
% 


switch nargin
  case 3
    verbose = true;
end
selector = lower(selector);

switch selector
  %------------------------------------------------------------------------
  % results in a [nframes x 15] matrix
  case {'g', 'p15'}
    if verbose
      fprintf('position of finger end effector (tip for thumb, dip for other fingers)\n');
    end
    % jointidx = name2index(skeleton.namemap, {'th-tip';'if-dip';'mf-dip';'rf-dip';'lf-dip'} );
    % % the data will be alligned as follows:
    % % x(th-tip) x(if-dip) ... x(lf-dip) y(th-tip) ... y(lf-dip) z(th-tip) ... z(lf-dip)
    % % sequential order of the data is not important for the segmentation!
    % T = [motion.jointtrajectories{jointidx}]';
    % featuredata = reshape(T, motion.numberofframes, 3*length(jointidx));
    % clear T;
    featuredata = jointPosition( skeleton,motion, {'th-tip';'if-dip';'mf-dip';'rf-dip';'lf-dip'});
    featuredata = [vertcat(featuredata{:})]';%reshape([featuredata{:}]',size(featuredata{1},2), 3*size(featuredata,1));    
  otherwise
end

%plot(featuredata);

return;