
function featuredata = jointPosition ( skeleton, motion, joints )
%
%
% INPUT
%   skeleton ... skeleton struct
%   motion ..... motion struct containing the joint trajectories
%   joints ..... string name of the joints to use or
%                cell array containing the string name of joints to use
%
% OUTPUT
%   featuredata ... <nfeatures x 1> cell array, 
%                   each row is a <3 x nframes> double vector holding the
%                   respective joint's position (x,y,z).
%
% EXAMPLE
%   jointPosition( skeleton,motion, {'th-tip';'if-dip';'mf-dip';'rf-dip';'lf-dip'});
%


if (isempty(motion.jointtrajectories))
  error ('Where''s the joint trajectories?!');
end %fi

jointidx = name2index(skeleton.namemap, joints, 'joint');

featuredata = motion.jointtrajectories(jointidx);

%%% concatenate all feature vectors, 
%%% i.e. x_f1, y_f1, z_f1, x_f2, ..., z_fn =>  n x 3 rows
% featuredata = vertcat(featuredata{:});

%%% concatenate all x, then all y and then all z data rows,
%%% i.e. x(f1), x(f2), ..., x(fn), y(f1), ..., y(fn), z(f1), ..., z(fn) => n x 3 rows
% featuredata = reshape([featuredata{:}]',size(featuredata(1),2), 3*size(featuredata,1));
%%% REMARK: not transposing the data in this method results in the data
%%% being arranged as follows: (row 1) x1_f1, y1_f1, z1_f1, x2_f1, y2_f1, z2_f1, ...
%%% and thus each line would have to be 3x#frames ... 

end % of function jointPosition