function [cuts,  timings, nnidx, nndists ] = HandMotionSegmentationA( data, varargin)
% 
% INPUT
%   data ... [dim x frames] feature data matrix with each column 
%            representing a frame / pose
%   varargin ... options in order to overwrite default options
%            ... ??? more???
%
% OUTPUT
%   cuts ...... found cuts in square representation (list of [start end]
%               entries), each row represents one cut/square.
%   timings ...
%   nnidx and nndists ... should not be output. This was for testing the
%   uni-bonn clustering (20150918)
%
% EXAMPLE
%   data = rand (15,600);
%   [cuts, timings] = HandMotionSegmentationA ( data );
%


 %% Global options
%  
%     options.fmat = data;
%  
  options.DEBUG = true;
%   options.DEBUG_FIND_MOTION_ACTIVITIES = false;
  options.executeFindMotionSimilarities = true;
%   options.nnidx = [];
%   options.nndists = [];
%     
  options.frameRate = 60;
    
  % number of nearest neighbors to compute
  options.k = size(data,2);
  % dimension of the input data
  options.dim = size(data,1);
    
  % generalized radius
  options.generalized_radius = 7;%0.0345*179; % Most important parameter!
%   options.generalized_radius = 0.3/sqrt(size(data,1)); % Most important parameter!
    
  % calculate frame window specific radius 
  options.radius = options.generalized_radius * sqrt( size(data,1) );
  
  % print timings for Activiy and Similarity computations
  options.PRINT_SEGMENTATION_TIMING = true;


%   options.min_path_length = options.frameRate / 4;

%     
  %% Find motion activities options
  options.generalized_radius_activities = 7;%0.0345*179;
%   options.generalized_radius_activities = 0.3/sqrt(size(data,1));
   
  % calculate frame window specific activity radius 
  options.radius_activities = options.generalized_radius_activities * sqrt( size(data,1) );

  % minimum number of nearest neighbors in a blob (nn_min_blob_size)

  % minimum number of frames between two blobs
  options.nn_min_blob_dist = floor(options.frameRate / 6);

  % minimum change in two successive start (resp. end) indices marking a relevant square
  % OR width of a 'band' within width a square is not counted as relevant
  options.ignoreband = 4;

  % minimal overlap of intervalls in order to be merged
  options.intervall_merge_thresh = 0.5;

%% Merge options
switch nargin
  case 1
    % do not to anything, everything is taken care of;
  case 2
    options = mergeOptions_local(varargin{1}, options);
  otherwise
    options = mergeOptions_local(varargin{1}, options);
    warning('wrong number of arguments, expected 2, ignoring additional inputs.');
end

  %% Re-calculate calculated values in case they changed
  % calculate frame window specific radius 
  options.radius = options.generalized_radius * sqrt( size(data,1) );
  % calculate frame window specific activity radius 
  options.radius_activities = options.generalized_radius_activities * sqrt( size(data,1) );

  if isfield(options,'reprojection')
  else
    options.reprojection = false;
  end
%% Start algorithm

  timings = {};

%% Find Motion Similarities
  tic;
  if (options.executeFindMotionSimilarities)
    [ nnidx, nndists ] = findMotionSimilarities( data, options );
  else
    nnidx = options.nnidx;
    nndists = options.nndists;
  end
  timings.Find_Motion_Similarities = toc;
  if options.PRINT_SEGMENTATION_TIMING
    fprintf('Find Motion Similarities\tcompleted in % 2f seconds.\n', timings.Find_Motion_Similarities);
  end



%% Find Motion Activities
  tic;
  frame_count = size(data,2);
  ssmimg = selfSimilarityMatrix(frame_count, nnidx, nndists);
  ssmimg(isnan(ssmimg)) = inf; %in case there were nan in nnidx. Otherwise findMainContour will return just one big square.
  %ks_sliderPlotSelfSimilarityThresh(ssmimg, [0,max(ssmimg(:))]);


  [rectbwd, rectfwd] = findMainContour(ssmimg, 0, options.radius_activities);

  rectbwd = [rectbwd, (1:frame_count)'];
  rectfwd = [(1:frame_count)', rectfwd];
%   if ~isempty(find(rectfwd1-rectfwd))
%     display('nempty');
%   end
%   if ~isempty(find(rectbwd1-rectbwd))
%     display('nempty');
%   end
  [rect_temp_b, rect_temp_f] = segmentationMethodA(rectbwd, rectfwd, options.ignoreband, options.nn_min_blob_dist);


% %look at result of segmentation
%   figure(40);
%   clf(40);
% 
%   drawSelfSimilarityMatrix (ssmimg, [0, options.radius]);%options.radius;% max(ssmimg(:))
%   hold on;
%   plotSquares([rect_temp_b(:,1)-0.5,rect_temp_b(:,2)+0.5], 'b',2.5);
%   plotSquares([rect_temp_f(:,1)-0.5,rect_temp_f(:,2)+0.5], 'r',2.5);
%   hold off;

  ssmimg_thresh = ssmimg;
  %merge overlapping intervals
  if options.reprojection
    ssmimg_thresh = ssmimg>options.radius_activities;
    rect_temp_b = mergeIntervals_checkReprojection(options.intervall_merge_thresh, {rect_temp_b},ssmimg_thresh,options.reprojection_coverage);
    rect_temp_f = mergeIntervals_checkReprojection(options.intervall_merge_thresh, {rect_temp_f},ssmimg_thresh,options.reprojection_coverage);
  else
    rect_temp_b = mergeIntervals(options.intervall_merge_thresh, {rect_temp_b});
    rect_temp_f = mergeIntervals(options.intervall_merge_thresh, {rect_temp_f});
  end

  % START merge fwd and bwd
  if options.reprojection
    rect = mergeIntervals_checkReprojection(options.intervall_merge_thresh, {rect_temp_b rect_temp_f}, ssmimg_thresh, options.reprojection_coverage);
  else
    rect = mergeIntervals(options.intervall_merge_thresh, {rect_temp_b rect_temp_f});
  end
  
  % output only squares that were found twice
  do_rect_plot = true;
  if isempty(rect)
    cuts = [];
    do_rect_plot = false;
  else
  
    cuts = rect(rect(:,5)~=1,:);
    cuts = cuts(:,1:2);
    
    % reduce squares overlapping in exactly one frame (decrease end index of first)
    temp = cuts(1:end-1,2)-cuts(2:end,1);
    temp_idx = find(~temp);
    if ~isempty(temp_idx)
      for kk = 1:length(temp_idx);
        cuts(temp_idx(kk),2) = cuts(temp_idx(kk),2)-1;
      end
    end
    
  end
  
  
%   %reproject
%   options.radius_activities;
%   binary_remove = logical(zeros(size(cuts,1),1));
%   for kk=1:size(cuts,1)
% %     figure(8);
% %     imagesc(ssmimg(cuts(kk,1):cuts(kk,2),cuts(kk,1):cuts(kk,2))>options.radius_activities);
%     a = sum(sum(ssmimg(cuts(kk,1):cuts(kk,2),cuts(kk,1):cuts(kk,2))>options.radius_activities));
%     b = (cuts(kk,2)-cuts(kk,1)+1)*(cuts(kk,2)-cuts(kk,1)+1);
%     if ((b-a)/b) < 0.95
%       binary_remove(kk) = true;
%     end
%   end
%   cuts(binary_remove,:) = [];
  
  
  timings.Find_Motion_Activities = toc;
  if options.PRINT_SEGMENTATION_TIMING
    fprintf('Find Motion Activities\t\tcompleted in % 2f seconds.\n', timings.Find_Motion_Activities);
  end
  
  


  
  %% some more plotting of results
  if (options.DEBUG)
    figure(40);
    clf(40);
    
    drawSelfSimilarityMatrix (ssmimg, [0, options.radius]);%options.radius;% max(ssmimg(:))


    hold on;
    plot(rectbwd(:,1),rectbwd(:,2), 'Color', 'g', 'LineWidth', 3);
    plot(rectfwd(:,2),rectfwd(:,1), 'Color', 'g', 'LineWidth', 3);
    hold off;

    %unclear_f = rect(find(rect(:,5)==1),:);
    %unclear_b = unclear_f(find(unclear_f(:,4)==1),:);
    %unclear_f = unclear_f(find(unclear_f(:,4)==2),:);
    %rect = rect(find(rect(:,5)~=1),:);
    if do_rect_plot
      unclear_f = rect(rect(:,5)==1,:);%get those that were not merged
      unclear_b = unclear_f(unclear_f(:,4)==1,:); % extract the ones from the first list
      unclear_f = unclear_f(unclear_f(:,4)==2,:); % extract the ones from the second list
      %rect = rect(rect(:,5)~=1,:);
      plotSquares([cuts(:,1)-0.5,cuts(:,2)+0.5], 'y',2.5);
      plotSquares([unclear_f(:,1)-0.5,unclear_f(:,2)+0.5], 'r',2.5);
      plotSquares([unclear_b(:,1)-0.5,unclear_b(:,2)+0.5], 'b',2.5);
    end
    
  end %fi options.DEBUG == true
  
end % of function

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [options_out] = mergeOptions_local( options, options_default )
% merge options for motion similarities and motion activities
% default options will be overwritten
%

  verbose = false;
  if isfield(options,'ABSOLUTE_SILENCE')
    verbose = ~options.ABSOLUTE_SILENCE;
  elseif isfield(options_default,'ABSOLUTE_SILENCE')
    verbose = ~options_default.ABSOLUTE_SILENCE;
  else
    verbose = true;
  end


  fields{2} = fieldnames(options);
  values{2} = struct2cell(options);
  fields{1} = fieldnames(options_default);
  values{1} = struct2cell(options_default);

  fields = cat(1,fields{:});
  values = cat(1,values{:});


  %last, damit die default-Werte �berschrieben werden
  [unique_fields,idx] = unique(fields, 'last');
  
  %% check if there are duplicates and if there are, check if there are fields that need to be re-computed
  warning_msg = [];
  recomp_radius_activities = -1;
  recomp_radius = -1;
  if numel(unique_fields) ~= numel(fields),
    duplicate_fields = fields;
    duplicate_fields (idx,:) = [];
    recomp_radius_activities = sum(strcmp('generalized_radius_activities',duplicate_fields)) - sum(strcmp('radius_activities',duplicate_fields));
    recomp_radius = sum(strcmp('generalized_radius',duplicate_fields)) - sum(strcmp('radius',duplicate_fields));
    temp = sprintf('\n  -> %s', duplicate_fields{:});
    warning_msg = sprintf('Overwriting default values for%s',temp);
  end
  
  
  fields = fields(idx,:);
  values = values(idx,:);

  options_out = cell2struct(values, fields);

  if (recomp_radius_activities>0) || (recomp_radius>0)
    warning_msg = sprintf('%s\n%s',warning_msg,'Recomputing, hence overwriting');
  end
  if (recomp_radius_activities > 0)
    %display('recompute radius_activities');
    options_out.radius_activities = options_out.generalized_radius_activities * sqrt(options_out.dim);
    warning_msg = sprintf('%s\n%s',warning_msg, '  -> radius_activities');
  end
  if (recomp_radius > 0)
    %display('recompute radius');
    options_out.radius = options_out.generalized_radius * sqrt(options_out.dim);
    warning_msg = sprintf('%s\n%s',warning_msg, '  -> radius');
  end
  
  if ~isempty(warning_msg) && verbose
    warning('%s\n', warning_msg);
  end

end