function [immat] = selfSimilarityMatrix(frame_count, nnidx, nndists)
% Construct self similarity matrix based on the nearest neighbor index map
% (nnidx) and their respective distances (nndists).
% This may be reveresed by  nndists = sort(immat,2).
%
% INPUT
%   frame_count ... number of frames in the motion
%   nnidx ......... nearest neighbour index map
%   nndists ....... nearest neighbour distances
%
% OUTPUT
%   immat ... self similarity matrix
%
% EXAMPLE
%   ssmimg_sparse = selfSimilarityMatrix(nframes, nnidx_filtered', nndists_filtered');
%
%

% % OLD
% immat = nan(frame_count);
% 
% for k=1:frame_count
%   idx = ~isnan(nnidx(:, k));
%   immat(k, nnidx(idx, k)) = nndists(idx, k);
% end %for

frame_count = size(nnidx,2);

immat = nan(frame_count);%nan(size(nnidx));
for k=1:frame_count
  idx = ~isnan(nnidx(:, k));
  immat(nnidx(idx, k),k) = nndists(idx, k);
end

end % of function selfSimilarityMatrix

% O(frame_count)