function overlap = computeIntervalOverlap( A, B )
% computeIntervalOverlap(A,B)
%
% Compute the overlap of two well formed intervals (i.e. for each interval 
% [x1,x2] holds x1<x2). 
%
% INPUT
%   A ... first intervall (vector whith A(1) <= A(2))
%   B ... second intervall (vector whith B(1) <= B(2))
% 
% OUTPUT
%   overlap ... width of overlap of the two intervals
%
% EXAMPLE
%   % overlap of 1
%   ov = computeIntervalOverlap( [a,b], [b,d] ); 
%
%   % overlap of b-a+1
%   ov = computeIntervalOverlap( [a,b], [a,b] ); 
% 
%   % overlap of 0
%   ov = computeIntervalOverlap( [0,1], [3,4] ); 
% 


% For two intervals [x1,x2] and [y1,y2] the following cases apply
%   x2 < y1 => no overlap (=> x1,x2,y1,y2)
%   x1 > y2 => no overlap (=> y1,y2,x1,x2)
% Or, put the other way around, the intervals overlap if there is a value c 
% which is present in both intervals. I.e.
%   c > x1 && c < x2 (or x1 <= c <= x2)
%   &&
%   c > y1 && c < y2 (or y1 <= c <= y2)
% which forms a condition
%   x1 <= y2 && y1 <= x2
tf = ( (A(1) <= B(2)) && (B(1) <= A(2)) );

if tf
  overlap = max(-1,min(A(2),B(2))-max(A(1), B(1)))+1;
else
  overlap = 0;
end

end % of function
