function rect = cuts2rects ( cuts, nframes )
% Convert a list of cuts (segmentation) to a list of squares, where each
% square is equivalent to a pair of sequential cuts.
%
% INPUT
%   cuts ...... list of cuts (indices/frames in the motion) from a segmentation
%   nframes ... length of the segmented motion in frames 
%
% OUTPUT
%   rect ... list of [start, end] frames, defining a square each
%

if (cuts(end) == nframes)
  start = [1 cuts(1:end-1)]; % each cuts represents the start of a new segment
  stop = [cuts(1:end-1)-1 nframes];
else
  start = [1 cuts]; % each cuts represents the start of a new segment
  stop = [cuts-1 nframes];
end

rect = [start' stop'];

end
