function [cuts_all,cuts_type] =  fillCutGaps(nframes, cuts, min_cut_width)
%
%
% INPUT
%   nframes ......... number of frames in the motion the cut squares came from
%   cuts ............ cuts in the motion (as cut squares)
%   min_cut_width ... minimal width of a cut square (smaller ones will be
%                     neglected)
% 
%  OUTPUT
%   cuts_all .... list of cut squares with filled gaps
%   cuts_type ... type of each cut (1 -> segment, 0 -> transition)
% 
% 


if nargin == 2
  min_cut_width = 2;
end

ncuts = size(cuts,1);

temp_cut = [[1; cuts(:,2)]+1 [cuts(:,1);nframes+1]-1];

% save for every rectangle if it was segmented (1) or not (0)
temp_cut(:,3) = 0;
cuts(:,3) = 1;

% merge cuts and sort according to first index
cuts_unseg = temp_cut;
[cuts_all, idx] = sortrows([cuts; cuts_unseg]);

% sort out cuts that are too short
valid = (cuts_all(:,2) - cuts_all(:,1)) >= (min_cut_width-1);

cuts_all = cuts_all(valid,:);

cuts_type = cuts_all(:,3);
cuts_all = cuts_all(:,1:2);
% 
% nallcuts = size(cuts_all,1);
% cuts_type = zeros(nallcuts,1);
% cuts_type(1:ncuts,:) = 1;
% cuts_type = cuts_type(idx,:);


end % of function fillCutGaps
