function drawSelfSimilarityMatrix ( ssm, minmax, information, parent_axis, colorMax )
% 
%
% INPUT
%   ssm ........... self similarity matrix
%   minmax ........ interesting range in the ssm
%   information ... (true) display information such as colorbar and mapping of values
%                   (false) do not display information
%                   default: true
%   parent_axis ... Parent axis of the image (axis to draw into)
% 
% OUTPUT
%   none
% 
% EXAMPLE
%  % calculate ssm
%  ssmimg = selfSimilarityMatrix(frame_count, nnidx, nndists);
%  % draw the ssm
%  drawSelfSimilarityMatrix(ssmimg, [0, options.radius]);
%


% %% old plotting method
% cmap = gray(256);
% %[min(ssmimg(:)) max(ssmimg(:))]/2.3176*254+1;
% %image(ssmimg/2.3176*254+1);%, [0,options.radius]);
% cmap(end,:) = [0 0 0.75];
% %imagesc(ssmimg, [0,2]);%options.radius
% 
% % if the number of nearest neighbors was not all nearest neighbors, there
% % are holes in the self similarity matrix. Make sure, this is reflected
% % when displayint it.
% ssm_for_plot = ssm;
% if ~isempty(find(isnan(ssm)))
%     cmap(1,:) = [0 0 0.95];
% end
% ssm_for_plot(isnan(ssm)) = -1000;
% imagesc(ssm_for_plot, minmax);
% colormap(cmap);

switch nargin 
  case 2
    information = true;
    has_parent_axis = false;
    colorMax = [0 0 0.75];
  case 3
    has_parent_axis = false;
    colorMax = [0 0 0.75];
  case 4
    has_parent_axis = true;
    colorMax = [0 0 0.75];
  case 5
    has_parent_axis = ~isempty(parent_axis);
end

%% new plotting method
ngraylevels = 256-2;
colorNaN = [0 0 0.95];
colorNaN = [0.75 0 0];
%colorMax = [0 0 0.75];

ssm_for_plot = ssm;
ssm_for_plot(isnan(ssm)) = 0;
ssm_for_plot(ssm > minmax(2)) = 0;
ssm_for_plot = mat2gray(ssm_for_plot);
% convert image to index map and the respective colormap
[ssm_for_plot, cmap] = gray2ind( ssm_for_plot, ngraylevels );

cmap = [colorNaN;...
       cmap; ...
       colorMax];
ssm_for_plot = ssm_for_plot+1;

has_NaN = 0;

if ~isempty(find(isnan(ssm)))
  ssm_for_plot(isnan(ssm)) = 0;
  has_NaN = 1;
end
ssm_for_plot(ssm > minmax(2)) = ngraylevels+1;
  
if has_parent_axis
  image(ssm_for_plot,'Parent',parent_axis);
  colormap(cmap);
else
  image(ssm_for_plot);
  colormap(cmap);
end


%% put information on mapping of values in the SSM and the colormap into the title and below the image
% NaN vorhanden und max(ssm(:)) > minmax(2) 
% => t \in ssm_for_plot \in [0,255]
%    UND cmap = [colorNaN, cmap with 254 gray levels, colorMax]
%               [ idx=0     idx=1...254               idx=255 ] => 256 values
%  ssm_for_plot [ idx=0     idx=1...254               idx=255 ]
%
% NaN vorhanden und max(ssm(:)) <= minmax(2) 
% => t \in ssm_for_plot \in [0,255]
%    UND cmap = [colorNaN, cmap with 254 gray levels, colorMax]
%               [ idx=0     idx=1...254               idx=255 ] => 256 values, von denen 255 angenommen werden
%  ssm_for_plot [ idx=0     idx=1...254                       ]

% NaN nicht vorhanden UND max(ssm(:)) > minmax(2)
% => t \in ssm_for_plot \in [0,255]
%    UND cmap = [colorNaN, cmap with 254 gray levels, colorMax]
%               [ idx=0    idx=1...254                idx=255 ] => 256 values, von denen 255 angenommen werden
%  ssm_for_plot [          idx=1...254                idx=255 ] 
% 
% NaN nicht vorhanden UND max(ssm(:)) <= minmax(2)
% => t \in ssm_for_plot \in [0,255]
%    UND cmap = [colorNaN, cmap with 254 gray levels, colorMax]
%               [ idx=0    idx=1...254                idx=255 ] => 256 values, von denen 254 angenommen werden 
%  ssm_for_plot [          idx=1...254                        ] 
titlestring = 'temp';
max_ssm = max(ssm(:));
if has_NaN
  if (minmax(2) >= max_ssm)
    titlestring = sprintf('NaN \\rightarrow \\{0\\}     \\wedge     [0,%.2f] \\rightarrow [1,254]', max_ssm);
  else
    titlestring = sprintf('NaN \\rightarrow \\{0\\}     \\wedge     [0,%.2f] \\rightarrow [1,254]     \\wedge     \\{x | x>%.2f\\} \\rightarrow \\{255\\} ', minmax(2),  minmax(2));
  end
else
  if (minmax(2) >= max_ssm)
    titlestring = sprintf('[0,%.2f] \\rightarrow [1,254]', max_ssm);
  else
    titlestring = sprintf('[0,%.2f] \\rightarrow [1,254]     \\wedge     \\{x | x>%.2f\\} \\rightarrow \\{255\\} ', minmax(2),  minmax(2));
  end
end


if information

  %%
  % adjust colorbar labels and also number of labels
  if has_parent_axis
    title(parent_axis, titlestring, 'Interpreter', 'tex');
    text(0,size(ssm,1)+size(ssm,1)*0.085, titlestring, 'Interpreter', 'tex'); % make sure this stands somewhere in the figure
    
    vcbh = colorbar('peer', parent_axis);
    set(parent_axis, 'Units', 'points');
    fig_pos_points = get(parent_axis, 'Position');
    set(parent_axis, 'Units', 'normalized');
    fig_space = min(fig_pos_points(3:4));
    font_size = get(parent_axis, 'FontSize');
    nticks = min(ceil(fig_space/(font_size*2)),10);
  else
    title(titlestring, 'Interpreter', 'tex');
    text(0,size(ssm,1)+size(ssm,1)*0.085, titlestring, 'Interpreter', 'tex'); % make sure this stands somewhere in the figure
    vcbh = colorbar;
    
    set(gca, 'Units', 'points');
    fig_pos_points = get(gca, 'Position');
    set(gca, 'Units', 'normalized');
    fig_space = min(fig_pos_points(3:4));
    font_size = get(gca, 'FontSize');
    nticks = min(ceil(fig_space/(font_size*2)),10);
  end
  
  vcbt = round(linspace(0,249,nticks));
  if (minmax(2) >= max_ssm)
    vcbal = linspace(0,max_ssm,254);
  else
    vcbal = linspace(0,minmax(2),254);
  end
  vcbnl = vcbal(vcbt+1);
  set(vcbh, 'YTick',vcbt);
  set(vcbh, 'YTickLabel',round(vcbnl*10)/10);
  
end

if has_parent_axis
  axis(parent_axis,'image');
else
  axis image;
end


end % of function drawSelfSimilarityMatrix
