function [] = plotSquares( v, varargin )
% plotSquares( v, color, linewidth, parentaxis )
% Draw a square in an image as specified by an interval containing the
% start and end point and a color.
%
% INPUT
%   v ... intervals in which the squares resides (start and end)
%   c ... (optional) color to draw the rectangle in
%   w ... (optional) width of the line
%   a ... (optional) parent axis
%
% OUTPUT
%   none
%
% EXAMPE
%   plotSquare ([qs qe], 'r');
%   plotSquare ([qs qe], [1 0.5 0]);
%

numvarargs = length(varargin);
% set defaults for optional inputs
optargs = {'b' 2 -1};

% now put these defaults into the valuesToUse cell array, 
% and overwrite the ones specified in varargin.
optargs(1:numvarargs) = varargin;
% or ...
% [optargs{1:numvarargs}] = varargin{:};

% Place optional args in memorable variable names
[c, w, a] = optargs{:};

nsquares = size(v,1);

for k = 1:nsquares
  if a~=-1
    line(...
      [v(k,1) v(k,1) v(k,2) v(k,2) v(k,1)], ...
      [v(k,1) v(k,2) v(k,2) v(k,1) v(k,1)], ...
      'LineWidth', w, 'Color', c, 'Parent',a);
  else
    line(...
      [v(k,1) v(k,1) v(k,2) v(k,2) v(k,1)], ...
      [v(k,1) v(k,2) v(k,2) v(k,1) v(k,1)], ...
      'LineWidth', w, 'Color', c);
  end
end

end