function [opt] = twenty16_HandSegmentation_loadOptions(featuredata)
% loads options to be used for segmentation
%
%  featuredata  ... is a <dim x nframes> double array
%

% should use similar options %%%%%%%%%%%%%%%%%%%%%

switch nargin
  case 0
    dim = 3*5*5;
    num_frames = 1000;
    warning('Using faked feature data of size %d x %d', dim, num_frames);
  otherwise
    %dim = size(featuredata,1);
    %nframes = size(featuredata,2);
    [dim,num_frames] = size(featuredata);
    %data = featuredata;
end


%% Global options
opt.DEBUG = true;
%   options.DEBUG_FIND_MOTION_ACTIVITIES = false;
opt.executeFindMotionSimilarities = true;
opt.frameRate = 60;

% number of nearest neighbors to compute
opt.k = num_frames;
% dimension of the input data
opt.dim = dim;

% generalized radius
opt.generalized_radius = 7;%0.0345*179; % Most important parameter!

% calculate frame window specific radius 
opt.radius = opt.generalized_radius * sqrt( dim );

% print timings for Activiy and Similarity computations
opt.PRINT_SEGMENTATION_TIMING = true;


%% Find motion activities options
opt.generalized_radius_activities = 7;%0.0345*179;
% calculate frame window specific activity radius 
opt.radius_activities = opt.generalized_radius_activities * sqrt( dim );

% minimum number of nearest neighbors in a blob (nn_min_blob_size)

% minimum number of frames between two blobs
opt.nn_min_blob_dist = floor(opt.frameRate / 6);

% minimum change in two successive start (resp. end) indices marking a relevant square
% OR width of a 'band' within width a square is not counted as relevant
opt.ignoreband = 4;

% minimal overlap of intervalls in order to be merged
opt.intervall_merge_thresh = 0.5;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  
end