% script_exampleusage_seg
% exampe usage segmentation code (stand-alone)

clear all; close all; clc;

%% add files to path
addpath(genpath('animation'));
addpath(genpath('annotation'));
addpath(genpath('features'));
addpath(genpath('findMotionSegments'));
addpath(genpath('findSimilarities'));
addpath(genpath('helpers'));
addpath(genpath('parser'));
addpath(genpath('plots'));
addpath(genpath('reproducibility'));
addpath(genpath('rotations'));


%% load motion from text file
segmentation.motion_filename = ['data' filesep '01_11_ex03-1-rad-004-grasp-su04.txt'];%'01_11_ex03-1-rad-004-grasp-su04.txt' %'01_ex01-rad-002-grasp-su01.txt' %'12_07_ex03-rad-052-grasp-su10.txt';
segmentation.skel = readSkeleton (['skel_files' filesep 'default.xmlskel'] ); 
segmentation.motion = loadDBKSmotion (segmentation.motion_filename, segmentation.skel, 'fixed-root');
segmentation.motion_annotation = loadDBKSmotion_annotation(segmentation.motion_filename);

%% compute feature data
featuredata = twenty16_HandSegmentation_loadFeaturedata(segmentation.skel, segmentation.motion);

%% load segmentation options
segmentation.opt_segment = twenty16_HandSegmentation_loadOptions(featuredata');
segmentation.opt_segment.DEBUG = false;

%% compute motion segments (aka cuts)
[segmentation.cuts, ~, ~, ~ ] = HandMotionSegmentationA(featuredata', segmentation.opt_segment);




%% compute self similarity
[ nnidx, nndists ] = findMotionSimilarities( featuredata', segmentation.opt_segment );
ssmimg = selfSimilarityMatrix(segmentation.motion.numberofframes, nnidx, nndists);
segmentation.ssmimg4plotting = ssmimg';
clear nnidx nndists ssmimg;

%% convert cuts to 'aligned' sequences for display (equal segments share same colour) 
[segmentation, seq, seqGT] = demo_compareToReference( segmentation );

%% draw thresholded self similarity matrix overlayed with found segments
figure(1);clf(1);
drawSelfSimilarityMatrix (segmentation.ssmimg4plotting, [0, segmentation.opt_segment.radius], false,[],[0.3 0.5 0.8]);
plotSquares([segmentation.cuts(:,1),segmentation.cuts(:,2)], 'y',2.5);
demo_plotLines(segmentation.cuts, 'y', 1);
title('Sparse self similarity matrix with segments');
demo_setAxisLabels();

%% draw found motion segments 
figure(2);clf(2);
if ~isempty(seqGT)
  subplot(2,1,1); 
  image(seqGT);
  title('Reference segmentation');
  xlabel('[frames]');
end
subplot(2,1,2);
image(seq);
title('Computed segmentation');
xlabel('[frames]');

%% draw animated hand coloured according to current motion segment
animateGUI(segmentation.skel, segmentation.motion, segmentation.cuts);



